# eric7.Plugins.VcsPlugins.vcsMercurial.HgServeDialog

Module implementing a dialog for the Mercurial server.

### Global Attributes

None

### Classes

HgServeDialog | Class implementing a dialog for the Mercurial server.

### Functions

None

## HgServeDialog

Class implementing a dialog for the Mercurial server.

### Derived from

EricMainWindow

### Class Attributes

None

### Class Methods

None

### Methods

HgServeDialog | Constructor
__appendText | Private method to append text to the end.
__procFinished | Private slot connected to the finished signal.
__readStderr | Private slot to handle the readyReadStandardError signal.
__readStdout | Private slot to handle the readyReadStandardOutput signal.
__startBrowser | Private slot to start a browser for the served repository.
__startServer | Private slot to start the Mercurial server.
__stopServer | Private slot to stop the Mercurial server.
closeEvent | Protected slot implementing a close event handler.

### Static Methods

None

#### HgServeDialog (Constructor)

HgServeDialog(vcs, path, parent=None)

Constructor

vcs (Hg)
  reference to the vcs object
path (str)
  path of the repository to serve
parent (QWidget)
  reference to the parent widget

#### HgServeDialog.__appendText

__appendText(txt, error=False)

Private method to append text to the end.

txt (str)
  text to insert
error (bool)
  flag indicating to insert error text

#### HgServeDialog.__procFinished

__procFinished(exitCode, exitStatus)

Private slot connected to the finished signal.

exitCode (int)
  exit code of the process
exitStatus (QProcess.ExitStatus)
  exit status of the process

#### HgServeDialog.__readStderr

__readStderr()

Private slot to handle the readyReadStandardError signal.

It reads the error output of the process and inserts it into the log.

#### HgServeDialog.__readStdout

__readStdout()

Private slot to handle the readyReadStandardOutput signal.

It reads the output of the process and inserts it into the log.

#### HgServeDialog.__startBrowser

__startBrowser()

Private slot to start a browser for the served repository.

#### HgServeDialog.__startServer

__startServer()

Private slot to start the Mercurial server.

#### HgServeDialog.__stopServer

__stopServer()

Private slot to stop the Mercurial server.

#### HgServeDialog.closeEvent

closeEvent(e)

Protected slot implementing a close event handler.

e (QCloseEvent)
  close event

Up